[<img src="https://img.shields.io/pypi/v/pyconfigurator.svg">](https://pypi.python.org/pypi/pyconfigurator)
[<img src="https://travis-ci.org/charsmith/configurator.svg?branch=master">](https://travis-ci.org/charsmith/configurator)

configurator
============

A package for easy configuration from command line arguments and ini files in python.
